django-geopostcodes
===================

Django modelling for `geopostcodes.com`_

NOTE: This repository does not include the actual data, you must purchase this
from `geopostcodes.com`_ and then import it as per the following documentation.

``django-geopostcodes`` supports Python 2.7, 3.3, 3.4 and pypy for Django 1.7
and 1.8.

Contents
--------

.. toctree::
 :maxdepth: 1

 installation
 usage
 developer
 internals/reference/index

License
-------

This software is licensed under the `MIT License`. See the `LICENSE`_
file in the top distribution directory for the full license text.

Author
------

Alex Hayes <alex@alution.com>

.. _Django: https://www.djangoproject.com/
.. _Models: https://docs.djangoproject.com/en/stable/topics/db/models/
.. _LICENSE: https://github.com/alexhayes/django-geopostcodes/blob/master/LICENSE
.. _geopostcodes.com: http://www.geopostcodes.com
